
# An example bravado config file to get the best results from bravado

config = {
    "response_metadata_class": "bravado.response.BravadoResponseMetadata",
    "disable_fallback_results": False,
    "validate_responses": True,
    "validate_requests": True,
    "validate_swagger_spec": True,
    "use_models": False,
}
